<%-- $Id: login.jsp 5827 2011-10-26 10:51:52Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	Login to BASE.
	If successful the request is ultimately forwarded to /user/index.jsp
	If unsuccessful an appropriate error message is displayed.

	@param login The login for the user.
	@param password The password for the user.
	@param nextpage The URL for the next page to show. If not
		specified the current page is reloaded

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.*"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.WebException"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%
	SessionControl sc = Base.getSessionControl(pageContext, true);
	String ID = sc.getId();
	String cmd = request.getParameter("cmd");
	String again = request.getParameter("again");
	String root = request.getContextPath()+"/";
	String redirect = Values.getStringOrNull(request.getParameter("redirect"));
	String errorTitle = null;
	String errorMessage = null;
	String login = request.getParameter("login");
		
	if ("Login".equals(cmd) || cmd == null)
	{
		String password = request.getParameter("password");
		try
		{
			if (sc.isLoggedIn()) sc.logout();
			sc.login(login, password, null);
		}
		catch (LoginException ex)
		{
			errorTitle = "Login failed";
			errorMessage = ex.getMessage();
		}
		catch (ItemNotFoundException ex)
		{
			errorTitle = "Login not found";
			errorMessage = Values.formatMessage(
				"The user with login {1} is not a registered user for BASE.",
				HTML.encodeTags(login)
			);
		}
		catch (InvalidPasswordException ex)
		{
			errorTitle = "Invalid password";
			errorMessage = Values.formatMessage(
				"The password for login {1} is not correct.",
				HTML.encodeTags(login)
			);
		}
		catch (PermissionDeniedException ex)
		{
			errorTitle = "Permission denied";
			errorMessage = Values.formatMessage(
				"You do not have permission to log in to BASE.<br>"+ex.getMessage(),
				HTML.encodeTags(login)
			);
		}

	}
	else if ("Impersonate".equals(cmd))
	{
		int userId = Values.getInt(request.getParameter("user_id"));
		String comment = request.getParameter("comment");
		SessionControl impersonated = sc.impersonateLogin(userId, comment);
		impersonated.setSessionSetting("impersonate.originalSessionControl", sc);
		DbControl dc = sc.newDbControl();
		try
		{
			impersonated.setSessionSetting("impersonate.originalUser", User.getById(dc, sc.getLoggedInUserId()));
		}
		finally
		{
			if (dc != null) dc.close();
		}
		sc = impersonated;
		if (redirect == null)
		{
			redirect = root + "my_base/index.jsp?ID=" + sc.getId();
		}
		else
		{
			redirect = redirect.replaceFirst("ID=[a-z0-9]*", "ID=" + sc.getId());
		}
	}
	else
	{
		throw new WebException("popup", "Invalid command", "The command {1} is not recognised as a valid command.", cmd);
	}
	
	if (sc.isLoggedIn())
	{
		int lastActiveProjectId = Values.getInt(sc.getUserClientSetting("projects.lastactive"));
		if (lastActiveProjectId != 0)
		{
			DbControl dc = sc.newDbControl();
			try
			{
				Project p = Project.getById(dc, lastActiveProjectId);
				sc.setActiveProject(p);
			}
			catch (Throwable t)
			{}
			finally
			{
				if (dc != null) dc.close();
			}
		}
	}
	
	if ("1".equals(again))
	{
		if (errorMessage != null)
		{
			throw new WebException("popup", errorTitle, errorMessage);
		}
		else
		{
			if (redirect == null)
			{
				response.sendRedirect(root+"common/close_popup.jsp?message=Login+successful&refresh_opener=1");
			}
			else
			{
				response.sendRedirect(root+"common/close_popup.jsp?message=Login+successful&redirect_opener="+HTML.urlEncode(redirect));
			}
		}
	}
	else
	{
		if (errorMessage != null)
		{
			response.sendRedirect(root+"main.jsp?ID="+ID+"&login="+HTML.urlEncode(login)+"&error="+HTML.urlEncode(errorMessage));
		}
		else
		{
			if (redirect == null)
			{
				response.sendRedirect(root+"my_base/index.jsp?refresh_menu=1&ID="+ID);
			}
			else
			{
				response.sendRedirect(redirect);
			}
		}
	}
%>
