<%-- $Id: view_message.jsp 5946 2012-02-03 13:18:47Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Message"
	import="net.sf.basedb.core.User"
	import="net.sf.basedb.core.Job"
	import="net.sf.basedb.core.PluginConfiguration"
	import="net.sf.basedb.core.BasicItem"
	import="net.sf.basedb.core.Nameable"
	import="net.sf.basedb.core.File"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.ParameterInfo"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="java.util.Date"
	import="java.util.Map"
	import="java.util.Set"
	import="java.util.List"
	import="java.util.Collections"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%!
	private static final Item itemType = Item.MESSAGE;
	private static final GuiContext guiContext = new GuiContext(itemType, GuiContext.Type.ITEM);
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String tab = Values.getString(request.getParameter("tab"), "properties");
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl();
try
{
	Message message = Message.getById(dc, itemId);
	message.setRead(true);
	boolean readJob = true;
	Job job = null;
	boolean readCurrentConfig = true;
	PluginConfiguration currentConfig = null;
	try
	{
		job = message.getJob();
	}
	catch (Exception ex)
	{
		readJob = false;
		readCurrentConfig = false;
	}
	if (job != null)
	{
		try
		{
			currentConfig = job.getPluginConfiguration();
		}
		catch (PermissionDeniedException ex)
		{
			readCurrentConfig = false;
		}
	}
	
	String title = "Message -- " + HTML.encodeTags(message.getName());;
	Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
	Formatter<Date> dateTimeFormatter = FormatterFactory.getDateTimeFormatter(sc);
	
	final boolean writePermission = message.hasPermission(Permission.WRITE);
	final boolean deletePermission = message.hasPermission(Permission.DELETE);
	final boolean isRemoved = message.isRemoved();
	final boolean isUsed = isRemoved && message.isUsed();
	final boolean deletePermanentlyPermission = deletePermission && !isUsed;
	%>

	<base:page type="popup" title="<%=title%>">
	<base:head scripts="tabcontrol.js" styles="tabcontrol.css,progressbar.css">
	<script language="javascript">
		function deleteItemPermanently()
		{
			Main.deleteItemPermanently('<%=ID%>', true, '<%=itemType.name()%>', <%=itemId%>, '&callback=itemDeleted');
		}
		function itemDeleted()
		{
			location.href = getRoot() + 'common/close_popup.jsp?ID=<%=ID%>&refresh_opener=1&wait=0';
		}
		function showUsingItems()
		{
			Main.showUsingItems('<%=ID%>', '<%=itemType.name()%>', <%=itemId%>);
		}
	</script>
	</base:head>
	<base:body>
		
		<h1><%=title%> <base:help tabcontrol="main" /></h1>
		
		<div class="content bottomborder">
			<table class="fullform outlined">
			<%
			if (message.isRemoved())
			{
				%>
				<tr>
					<td colspan="2" style="background: #E8E8E8; border-bottom: 1px solid #A0A0A0;">
					<div class="itemstatus">
						<base:icon 
							image="deleted.png"
							onclick="<%=deletePermanentlyPermission ? "deleteItemPermanently()" : null%>"
							tooltip="<%=deletePermanentlyPermission ? "Permanently delete this item" : null%>"
							visible="<%=isRemoved%>"> This item has been flagged for deletion<br></base:icon>
						<base:icon image="used.png" 
							onclick="showUsingItems()"
							tooltip="Show the items that are using this one"
							visible="<%=isUsed%>"> This item is used by other items and can't be permanently deleted<br></base:icon>
					</div>
					</td>
				</tr>
				<%
			}
			%>
			<tr>
				<th>Subject</th>
				<td><%=HTML.encodeTags(message.getName())%></td>
			</tr>
			<tr>
				<th>From</th>
				<td><%=HTML.encodeTags(message.getFrom())%></td>
			</tr>
			<%
			if (job != null)
			{
				%>
				<tr>
					<th>Job</td>
					<td><%=Base.getLinkedName(ID, job, false, false)%></td>
				</tr>
				<%
			}
			%>
			<tr>
				<th>Time sent</th>
				<td><%=dateTimeFormatter.format(message.getTimeSent())%></td>
			</tr>
			<tr class="dynamic">
				<th>Message</th>
				<td><%=HTML.niceFormat(message.getDescription())%></td>
			</tr>
			</table>
			</div>
		<base:buttongroup subclass="dialogbuttons">
			<base:button onclick="window.close()" title="Close" />
		</base:buttongroup>

	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.commit();
}

%>
